summaryrefslogtreecommitdiff
path: root/source3/include/smb.h
diff options
context:
space:
mode:
Diffstat (limited to 'source3/include/smb.h')
-rw-r--r--source3/include/smb.h24
1 files changed, 5 insertions, 19 deletions
diff --git a/source3/include/smb.h b/source3/include/smb.h
index 1b8f04f02e..43e402359f 100644
--- a/source3/include/smb.h
+++ b/source3/include/smb.h
@@ -393,12 +393,12 @@ typedef struct logon_info
} DOM_LOGON_ID;
-/* RC4_OWF */
-typedef struct rc4_owf_info
+/* ARC4_OWF */
+typedef struct arc4_owf_info
{
uint8 data[16];
-} RC4_OWF;
+} ARC4_OWF;
/* DOM_ID_INFO_1 */
@@ -409,8 +409,8 @@ typedef struct id_info_1
DOM_LOGON_ID logon_id; /* logon ID */
UNIHDR hdr_user_name; /* user name unicode header */
UNIHDR hdr_workgroup_name; /* workgroup name unicode header */
- RC4_OWF rc4_lm_owf; /* rc4 LM OWF Password */
- RC4_OWF rc4_nt_owf; /* rc4 NT OWF Password */
+ ARC4_OWF arc4_lm_owf; /* arc4 LM OWF Password */
+ ARC4_OWF arc4_nt_owf; /* arc4 NT OWF Password */
UNISTR2 uni_domain_name; /* domain name unicode string */
UNISTR2 uni_user_name; /* user name unicode string */
UNISTR2 uni_workgroup_name; /* workgroup name unicode string */
@@ -1040,10 +1040,8 @@ typedef struct
{
smb_shm_offset_t next_share_mode_entry;
int pid;
-#ifdef USE_OPLOCKS
uint16 op_port;
uint16 op_type;
-#endif /* USE_OPLOCKS */
int share_mode;
struct timeval time;
} share_mode_entry;
@@ -1052,10 +1050,8 @@ typedef struct
typedef struct
{
int pid;
-#ifdef USE_OPLOCKS
uint16 op_port;
uint16 op_type;
-#endif /* USE_OPLOCKS */
int share_mode;
struct timeval time;
} min_share_mode_entry;
@@ -1081,11 +1077,7 @@ struct connect_record
};
#ifndef LOCKING_VERSION
-#ifdef USE_OPLOCKS
#define LOCKING_VERSION 4
-#else /* USE_OPLOCKS */
-#define LOCKING_VERSION 3
-#endif /* USE_OPLOCKS */
#endif /* LOCKING_VERSION */
#if !defined(FAST_SHARE_MODES)
@@ -1101,11 +1093,7 @@ struct connect_record
#define SMF_FILENAME_LEN_OFFSET 8
#define SMF_HEADER_LENGTH 10
-#ifdef USE_OPLOCKS
#define SMF_ENTRY_LENGTH 20
-#else /* USE_OPLOCKS */
-#define SMF_ENTRY_LENGTH 16
-#endif /* USE_OPLOCKS */
/*
* Share mode record offsets.
@@ -1116,10 +1104,8 @@ struct connect_record
#define SME_SHAREMODE_OFFSET 8
#define SME_PID_OFFSET 12
-#ifdef USE_OPLOCKS
#define SME_PORT_OFFSET 16
#define SME_OPLOCK_TYPE_OFFSET 18
-#endif /* USE_OPLOCKS */
#endif /* FAST_SHARE_MODES */